@@ -7,6 +7,7 @@
 #include <boost/static_assert.hpp>
 #include <cpp-utils/pointer/unique_ref.h>
 #include <cpp-utils/pointer/unique_ref_boost_optional_gtest_workaround.h>
+#include <cpp-utils/system/stat.h>
 
 #include "../../fs_interface/Device.h"
 #include "../../fs_interface/Node.h"
@@ -29,12 +30,25 @@ public:
     "Given test fixture for instantiating the (type parameterized) FileSystemTest must inherit from FileSystemTestFixture"
   );
 
-  FileSystemTest(): fixture(), device(fixture.createDevice()) {}
+  FileSystemTest(): fixture(nullptr), device(nullptr) {
+      resetFilesystem(fspp::Context{fspp::relatime()});
+  }
 
-  ConcreteFileSystemTestFixture fixture;
-  cpputils::unique_ref<fspp::Device> device;
+  void resetFilesystem(fspp::Context&& context) {
+      device = nullptr;
+      fixture = nullptr;
+      fixture = std::make_unique<ConcreteFileSystemTestFixture>();
+      device = fixture->createDevice();
+      device->setContext(std::move(context));
+  }
 
-  static constexpr mode_t MODE_PUBLIC = S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IWOTH | S_IXOTH;
+  std::unique_ptr<ConcreteFileSystemTestFixture> fixture;
+  std::unique_ptr<fspp::Device> device;
+
+  static constexpr fspp::mode_t MODE_PUBLIC = fspp::mode_t()
+        .addUserReadFlag().addUserWriteFlag().addUserExecFlag()
+        .addGroupReadFlag().addGroupWriteFlag().addGroupExecFlag()
+        .addOtherReadFlag().addOtherWriteFlag().addOtherExecFlag();
 
   cpputils::unique_ref<fspp::Node> Load(const boost::filesystem::path &path) {
     auto loaded = device->Load(path);
@@ -61,17 +75,17 @@ public:
   }
 
   cpputils::unique_ref<fspp::Dir> CreateDir(const boost::filesystem::path &path) {
-    this->LoadDir(path.parent_path())->createDir(path.filename().native(), this->MODE_PUBLIC, 0, 0);
+    this->LoadDir(path.parent_path())->createDir(path.filename().string(), this->MODE_PUBLIC, fspp::uid_t(0), fspp::gid_t(0));
     return this->LoadDir(path);
   }
 
   cpputils::unique_ref<fspp::File> CreateFile(const boost::filesystem::path &path) {
-    this->LoadDir(path.parent_path())->createAndOpenFile(path.filename().native(), this->MODE_PUBLIC, 0, 0);
+    this->LoadDir(path.parent_path())->createAndOpenFile(path.filename().string(), this->MODE_PUBLIC, fspp::uid_t(0), fspp::gid_t(0));
     return this->LoadFile(path);
   }
 
-  cpputils::unique_ref<fspp::Symlink> CreateSymlink(const boost::filesystem::path &path) {
-    this->LoadDir(path.parent_path())->createSymlink(path.filename().native(), "/my/symlink/target", 0, 0);
+  cpputils::unique_ref<fspp::Symlink> CreateSymlink(const boost::filesystem::path &path, const boost::filesystem::path &target = "/my/symlink/target") {
+    this->LoadDir(path.parent_path())->createSymlink(path.filename().string(), target, fspp::uid_t(0), fspp::gid_t(0));
     return this->LoadSymlink(path);
   }
 
@@ -86,7 +100,44 @@ public:
   void EXPECT_IS_SYMLINK(const cpputils::unique_ref<fspp::Node> &node) {
     EXPECT_NE(nullptr, dynamic_cast<const fspp::Symlink*>(node.get()));
   }
+
+  void setAtimeOlderThanMtime(const boost::filesystem::path& path) {
+    auto node = device->Load(path).value();
+    auto st = node->stat();
+    st.atime.tv_nsec = st.mtime.tv_nsec - 1;
+    node->utimens(
+            st.atime,
+            st.mtime
+    );
+  }
+
+  void setAtimeNewerThanMtime(const boost::filesystem::path& path) {
+    auto node = device->Load(path).value();
+    auto st = node->stat();
+    st.atime.tv_nsec = st.mtime.tv_nsec + 1;
+    node->utimens(
+            st.atime,
+            st.mtime
+    );
+  }
+
+  void setAtimeNewerThanMtimeButBeforeYesterday(const boost::filesystem::path& path) {
+      auto node = device->Load(path).value();
+      auto st = node->stat();
+      const timespec now = cpputils::time::now();
+      const timespec before_yesterday {
+              /*.tv_sec = */ now.tv_sec - 60*60*24 - 1,
+              /*.tv_nsec = */ now.tv_nsec
+      };
+      st.atime = before_yesterday;
+      st.mtime.tv_nsec = st.atime.tv_nsec - 1;
+      node->utimens(
+              st.atime,
+              st.mtime
+      );
+  }
 };
+template<class ConcreteFileSystemTestFixture> constexpr fspp::mode_t FileSystemTest<ConcreteFileSystemTestFixture>::MODE_PUBLIC;
 
 
 #endif
