@@ -64,6 +64,7 @@ public:
     return CreateTree(CreateFourLevelMinDataWithLastLeafSize(size));
   }
 
+  // NOLINTNEXTLINE(misc-no-recursion)
   void EXPECT_IS_LEFTMAXDATA_TREE(const BlockId &blockId) {
     auto root = nodeStore->load(blockId).value();
     DataInnerNode *inner = dynamic_cast<DataInnerNode*>(root.get());
@@ -75,6 +76,7 @@ public:
     }
   }
 
+  // NOLINTNEXTLINE(misc-no-recursion)
   void EXPECT_IS_MAXDATA_TREE(const BlockId &blockId) {
     auto root = nodeStore->load(blockId).value();
     DataInnerNode *inner = dynamic_cast<DataInnerNode*>(root.get());
@@ -107,6 +109,7 @@ public:
     treeStore.load(blockId).get()->resizeNumBytes(size);
   }
 
+  // NOLINTNEXTLINE(misc-no-recursion)
   unique_ref<DataLeafNode> LastLeaf(const BlockId &blockId) {
     auto root = nodeStore->load(blockId).value();
     auto leaf = dynamic_pointer_move<DataLeafNode>(root);
@@ -124,7 +127,7 @@ public:
   uint64_t newSize;
   Data ZEROES;
 };
-INSTANTIATE_TEST_CASE_P(DataTreeTest_ResizeNumBytes_P, DataTreeTest_ResizeNumBytes_P,
+INSTANTIATE_TEST_SUITE_P(DataTreeTest_ResizeNumBytes_P, DataTreeTest_ResizeNumBytes_P,
   Combine(
     //Tree we're starting with
     Values<function<unique_ref<DataTree>(DataTreeTest_ResizeNumBytes*, uint32_t)>>(
