@@ -2,8 +2,7 @@
 
 #include "fspp/fs_interface/FuseErrnoException.h"
 
-using ::testing::_;
-using ::testing::StrEq;
+using ::testing::Eq;
 using ::testing::Throw;
 using ::testing::WithParamInterface;
 using ::testing::Values;
@@ -13,11 +12,11 @@ using namespace fspp::fuse;
 
 class FuseAccessErrorTest: public FuseAccessTest, public WithParamInterface<int> {
 };
-INSTANTIATE_TEST_CASE_P(FuseAccessErrorTest, FuseAccessErrorTest, Values(EACCES, ELOOP, ENAMETOOLONG, ENOENT, ENOTDIR, EROFS, EFAULT, EINVAL, EIO, ENOMEM, ETXTBSY));
+INSTANTIATE_TEST_SUITE_P(FuseAccessErrorTest, FuseAccessErrorTest, Values(EACCES, ELOOP, ENAMETOOLONG, ENOENT, ENOTDIR, EROFS, EFAULT, EINVAL, EIO, ENOMEM, ETXTBSY));
 
 TEST_P(FuseAccessErrorTest, ReturnedErrorIsCorrect) {
   ReturnIsFileOnLstat(FILENAME);
-  EXPECT_CALL(*fsimpl, access(StrEq(FILENAME), _))
+  EXPECT_CALL(*fsimpl, access(Eq(FILENAME), testing::_))
     .Times(AtLeast(1)).WillRepeatedly(Throw(FuseErrnoException(GetParam())));
 
   int error = AccessFileReturnError(FILENAME, 0);
