@@ -1,6 +1,9 @@
 #include "FuseFdatasyncTest.h"
 #include <fcntl.h>
 
+using cpputils::unique_ref;
+using cpputils::make_unique_ref;
+
 void FuseFdatasyncTest::FdatasyncFile(const char *filename) {
   int error = FdatasyncFileReturnError(filename);
   EXPECT_EQ(0, error);
@@ -9,12 +12,12 @@ void FuseFdatasyncTest::FdatasyncFile(const char *filename) {
 int FuseFdatasyncTest::FdatasyncFileReturnError(const char *filename) {
   auto fs = TestFS();
 
-  int fd = OpenFile(fs.get(), filename);
+  auto fd = OpenFile(fs.get(), filename);
 #ifdef F_FULLFSYNC
   // This is MacOSX, which doesn't know fdatasync
-  int retval = fcntl(fd, F_FULLFSYNC);
+  int retval = fcntl(fd->fd(), F_FULLFSYNC);
 #else
-  int retval = ::fdatasync(fd);
+  int retval = ::fdatasync(fd->fd());
 #endif
   if (retval != -1) {
     return 0;
@@ -23,9 +26,9 @@ int FuseFdatasyncTest::FdatasyncFileReturnError(const char *filename) {
   }
 }
 
-int FuseFdatasyncTest::OpenFile(const TempTestFS *fs, const char *filename) {
+unique_ref<OpenFileHandle> FuseFdatasyncTest::OpenFile(const TempTestFS *fs, const char *filename) {
   auto realpath = fs->mountDir() / filename;
-  int fd = ::open(realpath.c_str(), O_RDWR);
-  EXPECT_GE(fd, 0) << "Error opening file";
+  auto fd = make_unique_ref<OpenFileHandle>(realpath.string().c_str(), O_RDWR);
+  EXPECT_GE(fd->fd(), 0) << "Error opening file";
   return fd;
 }
