@@ -1,7 +1,6 @@
 #include "FuseFstatTest.h"
 
-using ::testing::StrEq;
-using ::testing::_;
+using ::testing::Eq;
 using ::testing::Return;
 using cpputils::unique_ref;
 using cpputils::make_unique_ref;
@@ -25,5 +24,5 @@ unique_ref<OpenFileHandle> FuseFstatTest::CreateFileAllowErrors(const TempTestFS
 }
 
 void FuseFstatTest::OnCreateAndOpenReturnFileDescriptor(const char *filename, int descriptor) {
-  EXPECT_CALL(*fsimpl, createAndOpenFile(StrEq(filename), _, _, _)).Times(1).WillOnce(Return(descriptor));
+  EXPECT_CALL(*fsimpl, createAndOpenFile(Eq(filename), testing::_, testing::_, testing::_)).Times(1).WillOnce(Return(descriptor));
 }
