@@ -5,11 +5,11 @@ using ::testing::Values;
 
 class FuseLstatReturnNlinkTest: public FuseLstatReturnTest<nlink_t>, public WithParamInterface<nlink_t> {
 private:
-  void set(struct stat *stat, nlink_t value) override {
+  void set(fspp::fuse::STAT *stat, nlink_t value) override {
     stat->st_nlink = value;
   }
 };
-INSTANTIATE_TEST_CASE_P(FuseLstatReturnNlinkTest, FuseLstatReturnNlinkTest, Values(
+INSTANTIATE_TEST_SUITE_P(FuseLstatReturnNlinkTest, FuseLstatReturnNlinkTest, Values(
     1,
     2,
     5,
@@ -17,12 +17,12 @@ INSTANTIATE_TEST_CASE_P(FuseLstatReturnNlinkTest, FuseLstatReturnNlinkTest, Valu
 ));
 
 TEST_P(FuseLstatReturnNlinkTest, ReturnedFileNlinkIsCorrect) {
-  struct ::stat result = CallDirLstatWithValue(GetParam());
+  fspp::fuse::STAT result = CallDirLstatWithValue(GetParam());
   EXPECT_EQ(GetParam(), result.st_nlink);
 }
 
 TEST_P(FuseLstatReturnNlinkTest, ReturnedDirNlinkIsCorrect) {
-  struct ::stat result = CallDirLstatWithValue(GetParam());
+  fspp::fuse::STAT result = CallDirLstatWithValue(GetParam());
   EXPECT_EQ(GetParam(), result.st_nlink);
 }
 
