@@ -1,6 +1,6 @@
 #include "testutils/FuseRenameTest.h"
 
-using ::testing::StrEq;
+using ::testing::Eq;
 using ::testing::Return;
 
 class FuseRenameFilenameTest: public FuseRenameTest {
@@ -9,7 +9,7 @@ class FuseRenameFilenameTest: public FuseRenameTest {
 TEST_F(FuseRenameFilenameTest, RenameFileRootToRoot) {
   ReturnIsFileOnLstat("/myfile");
   ReturnDoesntExistOnLstat("/myrenamedfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myfile"), StrEq("/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myfile"), Eq("/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/myfile", "/myrenamedfile");
@@ -19,7 +19,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileRootToNested) {
   ReturnIsFileOnLstat("/myfile");
   ReturnIsDirOnLstat("/mydir");
   ReturnDoesntExistOnLstat("/mydir/myrenamedfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myfile"), StrEq("/mydir/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myfile"), Eq("/mydir/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/myfile", "/mydir/myrenamedfile");
@@ -29,7 +29,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileNestedToRoot) {
   ReturnDoesntExistOnLstat("/myrenamedfile");
   ReturnIsDirOnLstat("/mydir");
   ReturnIsFileOnLstat("/mydir/myfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir/myfile"), StrEq("/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir/myfile"), Eq("/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir/myfile", "/myrenamedfile");
@@ -39,7 +39,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileNestedToNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsFileOnLstat("/mydir/myfile");
   ReturnDoesntExistOnLstat("/mydir/myrenamedfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir/myfile"), StrEq("/mydir/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir/myfile"), Eq("/mydir/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir/myfile", "/mydir/myrenamedfile");
@@ -50,7 +50,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileNestedToNested2) {
   ReturnIsDirOnLstat("/mydir/mydir2");
   ReturnIsFileOnLstat("/mydir/mydir2/myfile");
   ReturnDoesntExistOnLstat("/mydir/mydir2/myrenamedfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir/mydir2/myfile"), StrEq("/mydir/mydir2/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir/mydir2/myfile"), Eq("/mydir/mydir2/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir/mydir2/myfile", "/mydir/mydir2/myrenamedfile");
@@ -61,7 +61,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileNestedToNested_DifferentFolder) {
   ReturnIsDirOnLstat("/mydir2");
   ReturnIsFileOnLstat("/mydir/myfile");
   ReturnDoesntExistOnLstat("/mydir2/myrenamedfile");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir/myfile"), StrEq("/mydir2/myrenamedfile")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir/myfile"), Eq("/mydir2/myrenamedfile")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir/myfile", "/mydir2/myrenamedfile");
@@ -70,7 +70,7 @@ TEST_F(FuseRenameFilenameTest, RenameFileNestedToNested_DifferentFolder) {
 TEST_F(FuseRenameFilenameTest, RenameDirRootToRoot) {
   ReturnIsDirOnLstat("/mydir");
   ReturnDoesntExistOnLstat("/myrenameddir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir"), StrEq("/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir"), Eq("/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir", "/myrenameddir");
@@ -80,7 +80,7 @@ TEST_F(FuseRenameFilenameTest, RenameDirRootToNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/myrootdir");
   ReturnDoesntExistOnLstat("/myrootdir/myrenameddir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/mydir"), StrEq("/myrootdir/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/mydir"), Eq("/myrootdir/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/mydir", "/myrootdir/myrenameddir");
@@ -90,7 +90,7 @@ TEST_F(FuseRenameFilenameTest, RenameDirNestedToRoot) {
   ReturnDoesntExistOnLstat("/myrenameddir");
   ReturnIsDirOnLstat("/myrootdir");
   ReturnIsDirOnLstat("/myrootdir/mydir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myrootdir/mydir"), StrEq("/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myrootdir/mydir"), Eq("/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/myrootdir/mydir", "/myrenameddir");
@@ -100,7 +100,7 @@ TEST_F(FuseRenameFilenameTest, RenameDirNestedToNested) {
   ReturnIsDirOnLstat("/myrootdir");
   ReturnIsDirOnLstat("/myrootdir/mydir");
   ReturnDoesntExistOnLstat("/myrootdir/myrenameddir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myrootdir/mydir"), StrEq("/myrootdir/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myrootdir/mydir"), Eq("/myrootdir/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/myrootdir/mydir", "/myrootdir/myrenameddir");
@@ -111,7 +111,7 @@ TEST_F(FuseRenameFilenameTest, RenameDirNestedToNested2) {
   ReturnIsDirOnLstat("/myrootdir/myrootdir2");
   ReturnIsDirOnLstat("/myrootdir/myrootdir2/mydir");
   ReturnDoesntExistOnLstat("/myrootdir/myrootdir2/myrenameddir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myrootdir/myrootdir2/mydir"), StrEq("/myrootdir/myrootdir2/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myrootdir/myrootdir2/mydir"), Eq("/myrootdir/myrootdir2/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/myrootdir/myrootdir2/mydir", "/myrootdir/myrootdir2/myrenameddir");
@@ -122,7 +122,7 @@ TEST_F(FuseRenameFilenameTest, RenameDirNestedToNested_DifferentFolder) {
   ReturnIsDirOnLstat("/myrootdir2");
   ReturnIsDirOnLstat("/myrootdir/mydir");
   ReturnDoesntExistOnLstat("/myrootdir2/myrenameddir");
-  EXPECT_CALL(*fsimpl, rename(StrEq("/myrootdir/mydir"), StrEq("/myrootdir2/myrenameddir")))
+  EXPECT_CALL(*fsimpl, rename(Eq("/myrootdir/mydir"), Eq("/myrootdir2/myrenameddir")))
     .Times(1).WillOnce(Return());
 
   Rename("/myrootdir/mydir", "/myrootdir2/myrenameddir");
