@@ -3,13 +3,13 @@
 using ::testing::WithParamInterface;
 using ::testing::Values;
 
-class FuseStatfsReturnFfreeTest: public FuseStatfsReturnTest<fsfilcnt_t>, public WithParamInterface<fsfilcnt_t> {
+class FuseStatfsReturnFfreeTest: public FuseStatfsReturnTest<uint64_t>, public WithParamInterface<uint64_t> {
 private:
-  void set(struct ::statvfs *stat, fsfilcnt_t value) override {
+  void set(struct ::statvfs *stat, uint64_t value) override {
     stat->f_ffree = value;
   }
 };
-INSTANTIATE_TEST_CASE_P(FuseStatfsReturnFfreeTest, FuseStatfsReturnFfreeTest, Values(
+INSTANTIATE_TEST_SUITE_P(FuseStatfsReturnFfreeTest, FuseStatfsReturnFfreeTest, Values(
     0,
     10,
     256,
