@@ -1,6 +1,6 @@
 #include "testutils/FuseTruncateTest.h"
 
-using ::testing::StrEq;
+using ::testing::Eq;
 using ::testing::Return;
 using ::testing::WithParamInterface;
 using ::testing::Values;
@@ -8,7 +8,7 @@ using ::testing::Eq;
 
 class FuseTruncateSizeTest: public FuseTruncateTest, public WithParamInterface<fspp::num_bytes_t> {
 };
-INSTANTIATE_TEST_CASE_P(FuseTruncateSizeTest, FuseTruncateSizeTest, Values(
+INSTANTIATE_TEST_SUITE_P(FuseTruncateSizeTest, FuseTruncateSizeTest, Values(
     fspp::num_bytes_t(0),
     fspp::num_bytes_t(1),
     fspp::num_bytes_t(10),
@@ -18,7 +18,7 @@ INSTANTIATE_TEST_CASE_P(FuseTruncateSizeTest, FuseTruncateSizeTest, Values(
 
 TEST_P(FuseTruncateSizeTest, TruncateFile) {
   ReturnIsFileOnLstat(FILENAME);
-  EXPECT_CALL(*fsimpl, truncate(StrEq(FILENAME), Eq(GetParam())))
+  EXPECT_CALL(*fsimpl, truncate(Eq(FILENAME), Eq(GetParam())))
     .Times(1).WillOnce(Return());
 
   TruncateFile(FILENAME, GetParam());
