@@ -1,17 +1,13 @@
 #include "testutils/FuseUnlinkTest.h"
 
-using ::testing::_;
-using ::testing::StrEq;
-using ::testing::Return;
-using ::testing::Invoke;
-using ::testing::Action;
+using ::testing::Eq;
 
 class FuseUnlinkFilenameTest: public FuseUnlinkTest {
 };
 
 TEST_F(FuseUnlinkFilenameTest, Unlink) {
   ReturnIsFileOnLstat("/mydir");
-  EXPECT_CALL(fsimpl, unlink(StrEq("/mydir")))
+  EXPECT_CALL(*fsimpl, unlink(Eq("/mydir")))
     // After rmdir was called, lstat should return that it doesn't exist anymore
     // This is needed to make the ::rmdir() syscall pass.
     .Times(1).WillOnce(FromNowOnReturnDoesntExistOnLstat());
@@ -22,7 +18,7 @@ TEST_F(FuseUnlinkFilenameTest, Unlink) {
 TEST_F(FuseUnlinkFilenameTest, UnlinkNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsFileOnLstat("/mydir/mysubdir");
-  EXPECT_CALL(fsimpl, unlink(StrEq("/mydir/mysubdir")))
+  EXPECT_CALL(*fsimpl, unlink(Eq("/mydir/mysubdir")))
     // After rmdir was called, lstat should return that it doesn't exist anymore
     // This is needed to make the ::rmdir() syscall pass.
     .Times(1).WillOnce(FromNowOnReturnDoesntExistOnLstat());
@@ -34,7 +30,7 @@ TEST_F(FuseUnlinkFilenameTest, UnlinkNested2) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
   ReturnIsFileOnLstat("/mydir/mydir2/mydir3");
-  EXPECT_CALL(fsimpl, unlink(StrEq("/mydir/mydir2/mydir3")))
+  EXPECT_CALL(*fsimpl, unlink(Eq("/mydir/mydir2/mydir3")))
     // After rmdir was called, lstat should return that it doesn't exist anymore
     // This is needed to make the ::rmdir() syscall pass.
     .Times(1).WillOnce(FromNowOnReturnDoesntExistOnLstat());
