@@ -1,7 +1,6 @@
 #include "testutils/FuseUtimensTest.h"
 
-using ::testing::_;
-using ::testing::StrEq;
+using ::testing::Eq;
 using ::testing::Return;
 
 class FuseUtimensFilenameTest: public FuseUtimensTest {
@@ -9,7 +8,7 @@ class FuseUtimensFilenameTest: public FuseUtimensTest {
 
 TEST_F(FuseUtimensFilenameTest, UtimensFile) {
   ReturnIsFileOnLstat("/myfile");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/myfile"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/myfile"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/myfile", TIMEVALUE, TIMEVALUE);
@@ -18,7 +17,7 @@ TEST_F(FuseUtimensFilenameTest, UtimensFile) {
 TEST_F(FuseUtimensFilenameTest, UtimensFileNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsFileOnLstat("/mydir/myfile");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/mydir/myfile"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/mydir/myfile"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/mydir/myfile", TIMEVALUE, TIMEVALUE);
@@ -28,7 +27,7 @@ TEST_F(FuseUtimensFilenameTest, UtimensFileNested2) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
   ReturnIsFileOnLstat("/mydir/mydir2/myfile");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/mydir/mydir2/myfile"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/mydir/mydir2/myfile"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/mydir/mydir2/myfile", TIMEVALUE, TIMEVALUE);
@@ -36,7 +35,7 @@ TEST_F(FuseUtimensFilenameTest, UtimensFileNested2) {
 
 TEST_F(FuseUtimensFilenameTest, UtimensDir) {
   ReturnIsDirOnLstat("/mydir");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/mydir"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/mydir"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/mydir", TIMEVALUE, TIMEVALUE);
@@ -45,7 +44,7 @@ TEST_F(FuseUtimensFilenameTest, UtimensDir) {
 TEST_F(FuseUtimensFilenameTest, UtimensDirNested) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/mydir/mydir2"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/mydir/mydir2"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/mydir/mydir2", TIMEVALUE, TIMEVALUE);
@@ -55,7 +54,7 @@ TEST_F(FuseUtimensFilenameTest, UtimensDirNested2) {
   ReturnIsDirOnLstat("/mydir");
   ReturnIsDirOnLstat("/mydir/mydir2");
   ReturnIsDirOnLstat("/mydir/mydir2/mydir3");
-  EXPECT_CALL(*fsimpl, utimens(StrEq("/mydir/mydir2/mydir3"), _, _))
+  EXPECT_CALL(*fsimpl, utimens(Eq("/mydir/mydir2/mydir3"), testing::_, testing::_))
     .Times(1).WillOnce(Return());
 
   Utimens("/mydir/mydir2/mydir3", TIMEVALUE, TIMEVALUE);
