@@ -1,6 +1,4 @@
-#include <unistd.h>
 #include <sys/types.h>
-#include <sys/wait.h>
 #include "FuseThread.h"
 #include <csignal>
 #include <cpp-utils/assert/assert.h>
@@ -20,19 +18,19 @@ FuseThread::FuseThread(Fuse *fuse)
 
 void FuseThread::start(const bf::path &mountDir, const vector<string> &fuseOptions) {
   _child = thread([this, mountDir, fuseOptions] () {
-    _fuse->run(mountDir, fuseOptions);
+    _fuse->runInForeground(mountDir, fuseOptions);
   });
   //Wait until it is running (busy waiting is simple and doesn't hurt much here)
   while(!_fuse->running()) {}
 #ifdef __APPLE__
-  // On Mac OS X, _fuse->running() returns true too early, because osxfuse calls init() when it's not ready yet. Give it a bit time.
+  // On Mac OS X, _fuse->running() returns true too early, because macFUSE calls init() when it's not ready yet. Give it a bit time.
   std::this_thread::sleep_for(std::chrono::milliseconds(200));
 #endif
 }
 
 void FuseThread::stop() {
-  pthread_kill(_child.native_handle(), SIGINT);
-  bool thread_stopped = _child.try_join_for(seconds(5));
+  _fuse->stop();
+  bool thread_stopped = _child.try_join_for(seconds(10));
   ASSERT(thread_stopped, "FuseThread could not be stopped");
   //Wait until it is properly shutdown (busy waiting is simple and doesn't hurt much here)
   while (_fuse->running()) {}
