@@ -3,18 +3,19 @@
 #define MESSMER_FSPP_TEST_TESTUTILS_INMEMORYFILE_H_
 
 #include <cpp-utils/data/Data.h>
+#include <fspp/fs_interface/Types.h>
 
 class InMemoryFile {
 public:
   InMemoryFile(cpputils::Data data);
   virtual ~InMemoryFile();
 
-  int read(void *buf, size_t count, off_t offset) const;
+  fspp::num_bytes_t read(void *buf, fspp::num_bytes_t count, fspp::num_bytes_t offset) const;
 
   const void *data() const;
-  size_t size() const;
+  fspp::num_bytes_t size() const;
 
-  bool fileContentEquals(const cpputils::Data &expected, off_t offset) const;
+  bool fileContentEquals(const cpputils::Data &expected, fspp::num_bytes_t offset) const;
 
 protected:
   cpputils::Data _data;
@@ -24,14 +25,14 @@ class WriteableInMemoryFile: public InMemoryFile {
 public:
   WriteableInMemoryFile(cpputils::Data data);
 
-  void write(const void *buf, size_t count, off_t offset);
+  void write(const void *buf, fspp::num_bytes_t count, fspp::num_bytes_t offset);
 
   bool sizeUnchanged() const;
-  bool regionUnchanged(off_t offset, size_t count) const;
+  bool regionUnchanged(fspp::num_bytes_t offset, fspp::num_bytes_t count) const;
 
 private:
-  void _extendFileSizeIfNecessary(size_t size);
-  void _extendFileSize(size_t size);
+  void _extendFileSizeIfNecessary(fspp::num_bytes_t size);
+  void _extendFileSize(fspp::num_bytes_t size);
 
   cpputils::Data _originalData;
 };
